SystemOrganization addCategory: #'Neo4reSt-Tests'!

TestCase subclass: #N4BasicHttpTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Neo4reSt-Tests'!

!N4BasicHttpTest commentStamp: 'mu 4/22/2012 14:57' prior: 0!
self suite run!

!N4BasicHttpTest methodsFor: 'testing' stamp: 'mu 4/22/2012 14:57'!
testGet
	| cli resp urlString |
	cli := N4PortableUtil default httpClient.
	urlString := 'http://localhost:7474/db/data/'.
	resp := cli jsonGet: urlString.
	self assert: (resp code = 200)! !

!N4BasicHttpTest methodsFor: 'testing' stamp: 'mu 4/22/2012 15:00'!
testPost
	| cli resp urlString |
	cli := N4PortableUtil default httpClient.
	urlString := 'http://localhost:7474/db/data/'.
	resp := cli jsonPost: urlString.
	self assert: (resp code = 405) "POST not allowed"! !

TestCase subclass: #N4GraphModelTest
	instanceVariableNames: 'db initialNodeForTest'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Neo4reSt-Tests'!

!N4GraphModelTest commentStamp: 'mu 2/20/2012 00:33' prior: 0!
self suite run!

!N4GraphModelTest methodsFor: 'running' stamp: 'mu 2/13/2012 00:28'!
setUp
	| initialNode |
	db := N4GraphDb new.
	[initialNode := db initialNode] on: Error do: [:ex |
		self error: 'Neo4j is running? ', ex description printString].

	(initialNode outgoing: 'N4GraphModelTest') do: [:each | each delete].

	initialNodeForTest := initialNode relateToNewNode: 'N4GraphModelTest'
	
! !

!N4GraphModelTest methodsFor: 'testing' stamp: 'mu 2/13/2012 00:58'!
testBasicCreateNodes
	"self debug: #testBasicCreateNodes"
		
	| node1 node2 relation1 |
	node1 := db createNode.
	node2 := db createNode.
	relation1 := node1 relateTo: node2 type: #follows.
	
	self assert: ((node1 incoming) size = 0).
	initialNodeForTest relateTo: node1 type: #testBasicCreateNodes.
	self assert: ((node1 incoming) size = 1).

	self assert: ((initialNodeForTest outgoing: #testBasicCreateNodes) size = 1).
	self assert: ((node1 allRelationships) size = 2).
	self assert: ((node2 allRelationships) size = 1).
	
	self assert: ((node1 outgoing) size = 1).
	self assert: ((node2 incoming) size = 1).
	
	self assert: (relation1 id = node1 outgoing first id).
	self assert: (relation1 id = node2 incoming first id).
	
	(initialNodeForTest outgoing: #testBasicCreateNodes) first delete.
	
	self assert: ((node1 incoming) size = 0).

! !

!N4GraphModelTest methodsFor: 'testing' stamp: 'mu 2/16/2012 23:36'!
testBasicCreateNodesWithProperties
	"self debug: #testBasicCreateNodesWithProperties"
		
	| node1 node2 relation1 |
	node1 := db createNode: (#name-> 'start').
	node2 := db createNode: (#name-> 'end').
	relation1 := node1 relateTo: node2 type: #follows properties: (#score->100).
	
	self assert: ((node1 incoming) size = 0).
	initialNodeForTest relateTo: node1 type: #testBasicCreateNodesWithProperties.
	self assert: ((node1 incoming) size = 1).

	self assert: ((initialNodeForTest outgoing: #testBasicCreateNodesWithProperties) size = 1).
		
	self assert: ((node1 propertyAt: #name) = 'start').
	self assert: ((node2 propertyAt: #name) = 'end').
	self assert: ((relation1 propertyAt: #score) = 100).
	
	self assert: (node1 properties size = 1).
	node1 propertyAt: #name put: 'START'.
	self assert: ((node1 propertyAt: #name) = 'START').

	self assert: (relation1 properties size = 1).
	relation1 propertyAt: #score put: ((relation1 propertyAt: #score) + 200).
	self assert: ((relation1 propertyAt: #score) = 300).
	
	node2 propertyAt: #address put: 'Tokyo'.
	self assert: (node2 properties size = 2).
	
	node1 removePropertyAt: #name.
	node2 removePropertyAt: #name.
	relation1 removePropertyAt: #score.
	
	self assert: (node1 properties size = 0).
	self assert: (node2 properties size = 1).
	self assert: (relation1 properties size = 0).
	
	(initialNodeForTest outgoing: #testBasicCreateNodesWithProperties) first delete.
	
	self assert: ((node1 incoming) size = 0).

! !

!N4GraphModelTest methodsFor: 'testing' stamp: 'mu 2/20/2012 00:01'!
testBasicIndexers
	"self debug: #testBasicIndexers"
		
	| node1 node2 relation1 detectedNode1 detectedNode2 detectedRel1 |
	node1 := db createNode: (#name-> 'Masashi Umezawa').
	node2 := db createNode: (#name-> 'Smalltalk').
	relation1 := node1 relateTo: node2 type: #users properties: (#years->18).
	
	self assert: ((node1 incoming) size = 0).
	initialNodeForTest relateTo: node1 type: #testBasicIndexers.
	self assert: ((initialNodeForTest outgoing: #testBasicIndexers) size = 1).
	
	(db nodeIndexesNamed: 'people') addKey: #initial value: 'mu' for: node1.
	(db nodeIndexesNamed: 'programming languages') addKey: #extension value: 'st' for: node2.
	(db relationshipIndexesNamed: 'favorites') addKey: #rating value: 100 for: relation1.

	detectedNode1 := (db nodeIndexesNamed: 'people') detectWith: (#initial -> 'mu').
	detectedNode2 := (db nodeIndexesNamed: 'programming languages') detectWith: (#extension -> 'st').
	detectedRel1 := (db relationshipIndexesNamed: 'favorites') detectWith: (#rating -> 100).
	
	self assert: (node1 = detectedNode1).
	self assert: (node2 = detectedNode2).
	self assert: (relation1 = detectedRel1).
	
	(db nodeIndexesNamed: 'people') removeAllFor: node1.
	(db nodeIndexesNamed: 'programming languages') removeAllFor: node2.
	(db relationshipIndexesNamed: 'favorites') removeAllFor: relation1.
	
	detectedNode1 := (db nodeIndexesNamed: 'people') detectWith: (#initial -> 'mu').
	detectedNode2 := (db nodeIndexesNamed: 'programming languages') detectWith: (#extension -> 'st').
	detectedRel1 := (db relationshipIndexesNamed: 'favorites') detectWith: (#rating -> 100).
	
	self assert: (detectedNode1 isNil).
	self assert: (detectedNode2 isNil).
	self assert: (detectedRel1 isNil).

	(db nodeIndexesNamed: 'people') delete.
	(db nodeIndexesNamed: 'programming languages') delete.
	(db relationshipIndexesNamed: 'favorites') delete.
	
	(initialNodeForTest outgoing: #testBasicIndexers) first delete.
	
	self assert: ((node1 incoming) size = 0).

! !

!N4GraphModelTest methodsFor: 'testing' stamp: 'MasashiUmezawa 1/20/2013 01:13'!
testBasicIndexersWithSpecialCharacters
	"self debug: #testBasicIndexersWithSpecialCharacters"
		
	| node1 node2 relation1 detectedNode1 detectedNode2 detectedRel1 detectedRel2 |
	node1 := db createNode: (#name-> 'Masashi Umezawa').
	node2 := db createNode: (#name-> 'Smalltalk').
	relation1 := node1 relateTo: node2 type: #users properties: (#years->18).
	
	self assert: ((node1 incoming) size = 0).
	initialNodeForTest relateTo: node1 type: #testBasicIndexersWithSpecialCharacters.
	self assert: ((initialNodeForTest outgoing: #testBasicIndexersWithSpecialCharacters) size = 1).
	
	(db nodeIndexesNamed: 'address') removeAllFor: node1.
	(db nodeIndexesNamed: 'programming languages') removeAllFor: node2.
	(db relationshipIndexesNamed: 'my favorites') removeAllFor: relation1.
	(db relationshipIndexesNamed: 'my shares') removeAllFor: relation1.
	
	(db nodeIndexesNamed: 'address') addKey: #addressEn1 value: 'Tokyo, Japan' for: node1.
	(db nodeIndexesNamed: 'programming languages') addKey: #dialects value: 'Cincom Smalltalk / VW' for: node2.
	(db relationshipIndexesNamed: 'my favorites') addKey: #ratingEn value: 'over 100' for: relation1.
	(db relationshipIndexesNamed: 'my shares') addKey: #'shared with' value: 'You and me!!' for: relation1.

	detectedNode1 := (db nodeIndexesNamed: 'address') detectWith: (#addressEn1 -> 'Tokyo, Japan').
	detectedNode2 := (db nodeIndexesNamed: 'programming languages') detectWith: (#dialects -> 'Cincom Smalltalk / VW').
	detectedRel1 := (db relationshipIndexesNamed: 'my favorites') detectWith: (#ratingEn -> 'over 100').
	detectedRel2 := (db relationshipIndexesNamed: 'my shares') detectWith: (#'shared with' -> 'You and me!!').
	
	self assert: (node1 = detectedNode1).
	self assert: (node2 = detectedNode2).
	self assert: (relation1 = detectedRel1).
	self assert: (relation1 = detectedRel2).
	
	(db nodeIndexesNamed: 'address') removeAllFor: node1.
	(db nodeIndexesNamed: 'programming languages') removeAllFor: node2.
	(db relationshipIndexesNamed: 'my favorites') removeAllFor: relation1.
	(db relationshipIndexesNamed: 'my shares') removeAllFor: relation1.
	
	detectedNode1 := (db nodeIndexesNamed: 'address') detectWith: (#addressEn1 -> 'Tokyo, Japan').
	detectedNode2 := (db nodeIndexesNamed: 'programming languages') detectWith: (#dialects -> 'Cincom Smalltalk / VW').
	detectedRel1 := (db relationshipIndexesNamed: 'my favorites') detectWith: (#ratingEn -> 'over 100').
	detectedRel2 := (db relationshipIndexesNamed: 'my shares') detectWith: (#'shared with' -> 'You and me!!').
		
	self assert: (detectedNode1 isNil).
	self assert: (detectedNode2 isNil).
	self assert: (detectedRel1 isNil).
	self assert: (detectedRel2 isNil).

	(db nodeIndexesNamed: 'address') delete.
	(db nodeIndexesNamed: 'programming languages') delete.
	(db relationshipIndexesNamed: 'my favorites') delete.
	(db relationshipIndexesNamed: 'my shares') delete.
	
	(initialNodeForTest outgoing: #testBasicIndexersWithSpecialCharacters) first delete.
	
	self assert: ((node1 incoming) size = 0).

! !

!N4GraphModelTest methodsFor: 'testing' stamp: 'mu 2/20/2012 00:33'!
testBasicTraversal
	"self debug: #testBasicTraversal"
		
	| node1 node2 tra1 expectedRoles1 tra2 expectedRoles2|
	node1 := db createNode.
	node2 := db createNode.
	
	self assert: ((node1 incoming) size = 0).
	initialNodeForTest relateTo: node1 type: #testBasicTraversal.
	self assert: ((node1 incoming) size = 1).
	self assert: ((initialNodeForTest outgoing: #testBasicTraversal) size = 1).
	
	1 to: 10 do: [:idx | |newNode |
		newNode := node1 relateToNewNode: ('A>', idx printString).
		newNode relateTo: node2 type: (idx printString, '>B').
	].
	
	tra1 := node1 traversal: [:t | t breadthFirst; returnRelationship; maxDepth: 2].
	self assert: (tra1 size = 11).	
	expectedRoles1 := #('A>1' 'A>10' 'A>2' 'A>3' 'A>4' 'A>5' 'A>6' 'A>7' 'A>8' 'A>9' 'testBasicTraversal').
	self assert: ((tra1 collect: [:each | each type ]) asSortedCollection asArray = expectedRoles1).
	
	tra2 := node2 traversal: [:t | t breadthFirst; returnRelationship; maxDepth: 2].
	self assert: (tra2 size = 10).	
	expectedRoles2 :=  #('10>B' '1>B' '2>B' '3>B' '4>B' '5>B' '6>B' '7>B' '8>B' '9>B').
	self assert: ((tra2 collect: [:each | each type ]) asSortedCollection asArray = expectedRoles2).
	
	(initialNodeForTest outgoing: #testBasicTraversal) first delete.
	
	self assert: ((node1 incoming) size = 0).

! !

TestCase subclass: #N4UrlTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Neo4reSt-Tests'!

!N4UrlTest methodsFor: 'testing' stamp: 'MasashiUmezawa 1/20/2013 23:48'!
testBasicContatenate
	"self debug: #testBasicContatenate"
	| baseUrl baseUrl2 |
	baseUrl := N4Url baseUrlString: 'http://example.com'.
	baseUrl / 'sub' / 'subsub'.
	self assert: (baseUrl asString = 'http://example.com/sub/subsub').
	
	baseUrl2 := N4Url baseUrlString: 'http://example2.com/'.
	baseUrl2 / 'sub' / 'subsub'.
	self assert: (baseUrl2 asString = 'http://example2.com/sub/subsub').! !

!N4UrlTest methodsFor: 'testing' stamp: 'MasashiUmezawa 1/20/2013 23:55'!
testContatenate
	"self debug: #testContatenate"
	| baseUrl baseUrl2 baseUrl3 baseUrl4 |
	baseUrl := N4Url baseUrlString: 'http://example.com'.
	baseUrl / 'sub' // 'subsub'.
	self assert: (baseUrl asString = 'http://example.com/sub/subsub').
	
	baseUrl2 := N4Url baseUrlString: 'http://example.com/'.
	baseUrl2 / 'sub' / 1 / 'subsub'.
	self assert: (baseUrl2 asString = 'http://example.com/sub/1/subsub').
	
	baseUrl3 := N4Url baseUrlString: 'http://example.com/'.
	baseUrl3 / 'sub' / '1/2' / 'subsub'.
	self assert: (baseUrl3 asString = 'http://example.com/sub/1/2/subsub').
	
	baseUrl4 := N4Url baseUrlString: 'http://example.com/'.
	baseUrl4 / 'sub' // '1/2' / 'subsub'.
	self assert: (baseUrl4 asString = 'http://example.com/sub/1%2F2/subsub').! !
